Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/certbot/certbot.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'certbot-dns-route53/certbot_dns_route53/authenticator.py')
-rw-r--r--certbot-dns-route53/certbot_dns_route53/authenticator.py7
1 files changed, 4 insertions, 3 deletions
diff --git a/certbot-dns-route53/certbot_dns_route53/authenticator.py b/certbot-dns-route53/certbot_dns_route53/authenticator.py
index 53215ea1d..2987934a1 100644
--- a/certbot-dns-route53/certbot_dns_route53/authenticator.py
+++ b/certbot-dns-route53/certbot_dns_route53/authenticator.py
@@ -1,16 +1,17 @@
"""Shim around `~certbot_dns_route53.dns_route53` for backwards compatibility."""
import warnings
import zope.interface
from certbot import interfaces
-from certbot_dns_route53 import dns_route53
+from certbot_dns_route53._internal import dns_route53
@zope.interface.implementer(interfaces.IAuthenticator)
@zope.interface.provider(interfaces.IPluginFactory)
class Authenticator(dns_route53.Authenticator):
- """Shim around `~certbot_dns_route53.dns_route53.Authenticator` for backwards compatibility."""
+ """Shim around `~certbot_dns_route53._internal.dns_route53.Authenticator`
+ for backwards compatibility."""
hidden = True
@@ -1,16 +1,17 @@
-"""Shim around `~certbot_dns_route53.dns_route53` for backwards compatibility."""
+"""Shim around `~certbot_dns_route53._internal.dns_route53` for backwards compatibility."""
import warnings
import zope.interface